@@ -32,24 +32,30 @@
 #' @param skipped_columns a list of column indices to be excluded from parsing
 #' @param custom_non_data_line_markers (Optional) If a line in imported file starts with any character in given string it will NOT be imported. Empty string means all lines are imported, NULL means that default behaviour for given format will be used
 #' @param partition_by (Optional) Names of the columns the persisted dataset has been partitioned by.
+#' @param quotechar A hint for the parser which character to expect as quoting character. None (default) means autodetection.
+#' @param escapechar (Optional) One ASCII character used to escape other characters.
 #' @seealso \link{h2o.importFile}, \link{h2o.parseSetup}
 #' @export
 h2o.parseRaw <- function(data, pattern="", destination_frame = "", header=NA, sep = "", col.names=NULL,
                          col.types=NULL, na.strings=NULL, blocking=FALSE, parse_type = NULL, chunk_size = NULL,
-                         decrypt_tool = NULL, skipped_columns = NULL, custom_non_data_line_markers = NULL, partition_by=NULL) {
+                         decrypt_tool = NULL, skipped_columns = NULL, custom_non_data_line_markers = NULL, partition_by=NULL,
+                         quotechar = NULL, escapechar = "") {
+  single_quotes <- quotechar == "'"
   # Check and parse col.types in case col.types is supplied col.name = col.type vec
   if( length(names(col.types)) > 0 & typeof(col.types) != "list" ) {
     parse.params <- h2o.parseSetup(data, pattern="", destination_frame, header, sep, col.names, col.types = NULL,
                                    na.strings = na.strings, parse_type = parse_type, chunk_size = chunk_size,
                                    decrypt_tool = decrypt_tool, skipped_columns=skipped_columns,
-                                   custom_non_data_line_markers = custom_non_data_line_markers, partition_by = partition_by)
-    idx = match(names(col.types), parse.params$column_names)
-    parse.params$column_types[idx] = as.character(col.types)
+                                   custom_non_data_line_markers = custom_non_data_line_markers, 
+                                   partition_by = partition_by, single_quotes = single_quotes, escapechar = escapechar)
+    idx <- match(names(col.types), parse.params$column_names)
+    parse.params$column_types[idx] <- as.character(col.types)
   } else {
     parse.params <- h2o.parseSetup(data, pattern="", destination_frame, header, sep, col.names, col.types,
                                    na.strings = na.strings, parse_type = parse_type, chunk_size = chunk_size,
                                    decrypt_tool = decrypt_tool, skipped_columns=skipped_columns,
-                                   custom_non_data_line_markers = custom_non_data_line_markers, partition_by = partition_by)
+                                   custom_non_data_line_markers = custom_non_data_line_markers,
+                                   partition_by = partition_by, single_quotes = single_quotes, escapechar = escapechar)
   }
   for(w in parse.params$warnings){
     cat('WARNING:',w,'\n')
@@ -70,7 +76,8 @@ h2o.parseRaw <- function(data, pattern="", destination_frame = "", header=NA, se
             blocking = blocking,
             decrypt_tool = .decrypt_tool_id(parse.params$decrypt_tool),
             skipped_columns = paste0("[", paste(parse.params$skipped_columns, collapse=','), "]"),
-            partition_by = .collapse.array(parse.params$partition_by)
+            partition_by = .collapse.array(parse.params$partition_by),
+            escapechar = parse.params$escapechar
             )
   if(!is.null(custom_non_data_line_markers)){
     parse.params <- append(parse.params,list(custom_non_data_line_markers = custom_non_data_line_markers))
@@ -132,11 +139,13 @@ h2o.parseRaw <- function(data, pattern="", destination_frame = "", header=NA, se
 #'
 #' Get a parse setup back for the staged data.
 #' @inheritParams h2o.parseRaw
+#' @param single_quotes If set to true, the parser expects single quotes. False for double quotes (default).
+#' @param escapechar (Optional) One ASCII character used to escape other characters.
 #' @seealso \link{h2o.parseRaw}
 #' @export
 h2o.parseSetup <- function(data, pattern="", destination_frame = "", header = NA, sep = "", col.names = NULL, col.types = NULL,
                            na.strings = NULL, parse_type = NULL, chunk_size = NULL, decrypt_tool = NULL, skipped_columns = NULL,
-                           custom_non_data_line_markers = NULL, partition_by=NULL) {
+                           custom_non_data_line_markers = NULL, partition_by=NULL, single_quotes = FALSE, escapechar = "") {
 
   # Allow single frame or list of frames; turn singleton into a list
   if( is.H2OFrame(data) ) data <- list(data)
@@ -145,6 +154,7 @@ h2o.parseSetup <- function(data, pattern="", destination_frame = "", header = NA
   .key.validate(destination_frame)
   if(!(is.na(header) || is.logical(header))) stop("`header` cannot be of class ", class(header))
   if(!is.character(sep) || length(sep) != 1L || is.na(sep)) stop("`sep` must a character string")
+  if(!is.character(escapechar) || length(escapechar) != 1L || is.na(escapechar)) stop("`escapechar` must be a character string")
 
   # begin the setup
   # setup the parse parameters here
@@ -159,7 +169,11 @@ h2o.parseSetup <- function(data, pattern="", destination_frame = "", header = NA
   }
 
   if (!is.null(skipped_columns)) {
-    skipped_columns = sort(skipped_columns)
+    skipped_columns <- sort(skipped_columns)
+  }
+  
+  if(is.logical(single_quotes) && length(single_quotes) == 1L && !is.na(single_quotes)){
+    parseSetup.params$single_quotes <- single_quotes
   }
   
   # Prep srcs: must be of the form [src1,src2,src3,...]
@@ -174,6 +188,9 @@ h2o.parseSetup <- function(data, pattern="", destination_frame = "", header = NA
   # set field sep
   if( nzchar(sep) ) parseSetup.params$separator <- .asc(sep)
 
+  # set field sep
+  if( nzchar(escapechar) ) parseSetup.params$escapechar <- .asc(escapechar)  
+
   # check the na.strings
   if( !is.null(na.strings) ) parseSetup.params$na_strings <- .collapse.array(na.strings)
 
@@ -286,7 +303,8 @@ h2o.parseSetup <- function(data, pattern="", destination_frame = "", header = NA
         decrypt_tool       = parseSetup$decrypt_tool,
         skipped_columns    = parseSetup$skipped_columns,
         custom_non_data_line_markers = parseSetup$custom_non_data_line_markers,
-        partition_by       = parseSetup$partition_by
+        partition_by       = parseSetup$partition_by,
+        escapechar        = parseSetup$escapechar
         )
 }
 
